package com.ruoyi.web.controller.app;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.RlUser;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.model.RlModel;
import com.ruoyi.system.domain.agent.RlAgent;
import com.ruoyi.system.domain.city.RlCity;
import com.ruoyi.system.domain.city.RlCityQuery;
import com.ruoyi.system.domain.store.StoreQuery;
import com.ruoyi.system.service.IRlAgentService;
import com.ruoyi.system.service.IRlCityService;
import com.ruoyi.system.service.IRlModelService;
import com.ruoyi.system.service.ISysDictDataService;
import com.ruoyi.system.service.store.RlStoreService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

/**
 * app接口（不需要登录的）
 *  校验
 * @author ruoyi
 */
@RestController
@RequestMapping("/app")
public class AppController extends BaseController
{

    @Resource
    private IRlCityService rlCityService;

    @Autowired
    private ISysDictDataService dictDataService;

    @Resource
    private IRlAgentService rlAgentService;

    @Autowired
    private IRlModelService eModelService;

    @Autowired
    private RlStoreService storeService;

    /**
     * 查询城市列表
     */
    @GetMapping("/city/list")
    public AjaxResult cityList(RlCityQuery city)
    {
        logger.info("查询城市列表：【city="+city+"】");
        List<RlCity> list = rlCityService.selectRlCityList(city);
        return success(list);
    }

    /**
     * 获取出租周期列表
     */
    @GetMapping("/getRentalPeriod")
    public AjaxResult cityList()
    {
        SysDictData sysDictData = new SysDictData();
        sysDictData.setDictType("rl_rental_period");
        List<SysDictData> list = dictDataService.selectDictDataList(sysDictData);
        return success(list);
    }

    /**
     * 根据城市id获取代理商
     */
    @GetMapping("/getAgentByCityId")
    public AjaxResult getAgentByCityId(Long cityId)
    {
        logger.info("根据城市id获取代理商：【cityId="+cityId+"】");
        return success(rlAgentService.selectRlAgentByCityId(cityId));
    }


    /**
     * 根据城市id获取车型列表
     */
    @GetMapping("/getModelListByCityId")
    public AjaxResult getModelListByCityId(Long cityId)
    {
        logger.info("根据城市id获取车型列表：【cityId="+cityId+"】");
        RlAgent rlAgent = rlAgentService.selectRlAgentByCityId(cityId);
        if(rlAgent!=null){
            return success(eModelService.selectEModelListByAgentId(rlAgent.getAgentId()));
        }
        return error("代理商不存在");
    }

    /**
     * 根据定位获取哪个城市
     */
    @GetMapping("/getCity")
    public AjaxResult getCity(String lon,String lat)
    {
        logger.info("根据定位获取哪个城市：【lon="+lon+",lat="+lat+"】");
        AjaxResult ajax = AjaxResult.success();
        String city = rlCityService.getCityByLocation(lon,lat);
        ajax.put(AjaxResult.DATA_TAG, city);
        return ajax;
    }

    /**
     * 根据定位获取详细地址
     */
    @GetMapping("/getAddress")
    public AjaxResult getAddress(String lon,String lat)
    {
        logger.info("根据定位获取哪个城市：【lon="+lon+",lat="+lat+"】");
        AjaxResult ajax = AjaxResult.success();
        String city = rlCityService.getAddressByLocation(lon,lat);
        ajax.put(AjaxResult.DATA_TAG, city);
        return ajax;
    }


    /**
     * 根据店铺id获取店铺详情
     */
    @GetMapping("/getStore")
    public AjaxResult getStore(Long storeId)
    {
        logger.info("根据城市id获取车型列表：【storeId="+storeId+"】");
        return success(storeService.selectSmStoreById(storeId));
    }

    /**
     * 根据代理商id获取店铺列表
     */
    @GetMapping("/getStoreListByAgentId")
    public AjaxResult getStoreListByAgentId(Long agentId,String lon,String lat)
    {
        logger.info("根据代理商id获取店铺列表：【agentId="+agentId+",lon="+lon+",lat="+lat+"】");
        StoreQuery storeQuery = new StoreQuery();
        storeQuery.setAgentId(agentId);
        storeQuery.setPhoneLon(lon);
        storeQuery.setPhoneLat(lat);
        return success(storeService.selectSmStoreList(storeQuery));
    }





}
